==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/awt/XDevice.hpp <==
#ifndef _COM_SUN_STAR_AWT_XDEVICE_HPP_
#define _COM_SUN_STAR_AWT_XDEVICE_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_AWT_XDEVICE_HDL_
#include "com/sun/star/awt/XDevice.hdl"
#endif

#ifndef _COM_SUN_STAR_AWT_XDISPLAYBITMAP_HPP_
#include "com/sun/star/awt/XDisplayBitmap.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_FONTDESCRIPTOR_HPP_
#include "com/sun/star/awt/FontDescriptor.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_XDEVICE_HPP_
#include "com/sun/star/awt/XDevice.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_XFONT_HPP_
#include "com/sun/star/awt/XFont.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_XGRAPHICS_HPP_
#include "com/sun/star/awt/XGraphics.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_XBITMAP_HPP_
#include "com/sun/star/awt/XBitmap.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XINTERFACE_HPP_
#include "com/sun/star/uno/XInterface.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_DEVICEINFO_HPP_
#include "com/sun/star/awt/DeviceInfo.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XDevice >* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.awt.XDevice" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

::com::sun::star::uno::Type const & ::com::sun::star::awt::XDevice::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::awt::XDevice > * >(0));
}

#endif // _COM_SUN_STAR_AWT_XDEVICE_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/awt/XDevice.hpp <==
#ifndef _COM_SUN_STAR_AWT_XDEVICE_HPP_
#define _COM_SUN_STAR_AWT_XDEVICE_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_AWT_XDEVICE_HDL_
#include "com/sun/star/awt/XDevice.hdl"
#endif

#ifndef _COM_SUN_STAR_AWT_XDISPLAYBITMAP_HPP_
#include "com/sun/star/awt/XDisplayBitmap.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_FONTDESCRIPTOR_HPP_
#include "com/sun/star/awt/FontDescriptor.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_XDEVICE_HPP_
#include "com/sun/star/awt/XDevice.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_XFONT_HPP_
#include "com/sun/star/awt/XFont.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_XGRAPHICS_HPP_
#include "com/sun/star/awt/XGraphics.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_XBITMAP_HPP_
#include "com/sun/star/awt/XBitmap.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XINTERFACE_HPP_
#include "com/sun/star/uno/XInterface.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_DEVICEINFO_HPP_
#include "com/sun/star/awt/DeviceInfo.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace awt {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::awt::XDevice const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.awt.XDevice" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::uno::Reference< ::com::sun::star::awt::XDevice > const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::uno::Reference< ::com::sun::star::awt::XDevice > >::get();
}

::com::sun::star::uno::Type const & ::com::sun::star::awt::XDevice::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::awt::XDevice > * >(0));
}

#endif // _COM_SUN_STAR_AWT_XDEVICE_HPP_
